using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.IO;
using System.Reflection;
using System.Windows.Forms;

namespace TexturePicker
{
	/// <summary>
	/// Summary description for ExportProgress.
	/// </summary>
	public class ExportProgress : TexturePicker.MoveAnywhereForm
	{
		/************************************************
		 * Member Variables
		 ***********************************************/
		private bool cancel = false;

		/************************************************
		 * Designer Variables
		 ***********************************************/		
		private System.Windows.Forms.Button btnCancel;
		private System.Windows.Forms.FolderBrowserDialog folderBrowser;
		private System.Windows.Forms.Label lblTextureName;
		private System.Windows.Forms.ProgressBar pbTexture;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		/// <summary>
		/// A progress dialog for export.
		/// </summary>
		public ExportProgress()
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			//
			// TODO: Add any constructor code after InitializeComponent call
			//
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.folderBrowser = new System.Windows.Forms.FolderBrowserDialog();
			this.lblTextureName = new System.Windows.Forms.Label();
			this.btnCancel = new System.Windows.Forms.Button();
			this.pbTexture = new System.Windows.Forms.ProgressBar();
			this.SuspendLayout();
			// 
			// lblTextureName
			// 
			this.lblTextureName.AutoSize = true;
			this.lblTextureName.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.lblTextureName.Location = new System.Drawing.Point(4, 8);
			this.lblTextureName.Name = "lblTextureName";
			this.lblTextureName.Size = new System.Drawing.Size(86, 18);
			this.lblTextureName.TabIndex = 0;
			this.lblTextureName.Text = "TextureName";
			// 
			// btnCancel
			// 
			this.btnCancel.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.btnCancel.Location = new System.Drawing.Point(312, 60);
			this.btnCancel.Name = "btnCancel";
			this.btnCancel.TabIndex = 7;
			this.btnCancel.Text = "Cancel";
			this.btnCancel.Click += new System.EventHandler(this.btnCancel_Click);
			// 
			// pbTexture
			// 
			this.pbTexture.Location = new System.Drawing.Point(4, 36);
			this.pbTexture.Name = "pbTexture";
			this.pbTexture.Size = new System.Drawing.Size(384, 16);
			this.pbTexture.TabIndex = 9;
			this.pbTexture.Value = 80;
			// 
			// ExportProgress
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.CancelButton = this.btnCancel;
			this.ClientSize = new System.Drawing.Size(394, 90);
			this.Controls.Add(this.pbTexture);
			this.Controls.Add(this.btnCancel);
			this.Controls.Add(this.lblTextureName);
			this.Name = "ExportProgress";
			this.ResumeLayout(false);

		}
		#endregion

		/************************************************
		 * Internal Methods
		 ***********************************************/

		/************************************************
		 * Overrides / Event Handlers
		 ***********************************************/		
		private void btnCancel_Click(object sender, System.EventArgs e)
		{
			cancel = true;
			btnCancel.Enabled = false;
		}

		/************************************************
		 * Methods
		 ***********************************************/
		/// <summary>
		/// Advances the texture counter and updates the display name.
		/// </summary>
		/// <param name="texture">
		/// The texture that is currently being exported.
		/// </param>
		/// <returns>
		/// true if the export process should continue; otherwise false.
		/// </returns>
		public bool NextTexture(Texture texture)
		{
			pbTexture.Value++;
			lblTextureName.Text = texture.Name;
			lblTextureName.Refresh();
			return !cancel;
		}

		/// <summary>
		/// Resets the export progress dialog to show the stats of an export.
		/// </summary>
		public void Reset()
		{
			// Reset cancel and current texture info
			cancel = false;
			btnCancel.Enabled = true;
			pbTexture.Value = 0;
			pbTexture.Maximum = 1;
			lblTextureName.Text = string.Empty;
		}

		/************************************************
		 * Properties
		 ***********************************************/
		/// <summary>
		/// Gets or sets the index of the currently exported texture.
		/// </summary>
		public int CurrentTexture
		{
			get
			{
				return pbTexture.Value;
			}
			set
			{
				pbTexture.Value = value;
			}
		}

		/// <summary>
		/// Gets or sets the total number of textures to be exported.
		/// </summary>
		public int TextureCount
		{
			get
			{
				return pbTexture.Maximum;
			}
			set
			{
				pbTexture.Maximum = value;
			}
		}
	}
}
